#!/bin/sh
CLEANDB=$1
: ${CLEANDB:="0"}
export PATH=/usr/local/bin:/usr/bin:/bin
/bin/date +%s > /var/local/upgrade.txt
MAC=$(cat /sys/class/net/eth0/address)
EVNT_HWID=`rtest sql "SELECT HwID FROM Hardware WHERE HwMac = '$MAC' AND HwDeleted=0;" | awk 'FNR == 2 {gsub (/"/, "", $2); print $2}'`
TIME_UTC=$(rtest sql "SELECT strftime('%s', 'now', 'localtime');" | tail -1)
TIME=${TIME_UTC:4:10}
echo "Checking correct CPU type"
CPU_TYPE=`lscpu | awk 'FNR == 1 {print substr($2,0,3)}'`
if [ "$CPU_TYPE" = "arm" ]
then
    echo "CPU type OK ,$CPU_TYPE"
    EVENT_DATA="Replicator: 1.7.004 SysHwRWX: 1.7.125 SysFCGI: 1.7.122"
    EVENT_QUERY="INSERT INTO Events (EvntDateTime, EvntDscID, UsrID, HwID, EvntData) VALUES($TIME, 2008, 0, $EVNT_HWID, \"$EVENT_DATA\");"
    rtest sql "$EVENT_QUERY"
else
    echo "CPU type ERROR: $CPU_TYPE expected arm"
    EVENT_DATA="Wrong CPU type ($CPU_TYPE) expected arm"
    EVENT_QUERY="INSERT INTO Events (EvntDateTime, EvntDscID, UsrID, HwID, EvntData) VALUES($TIME, 2003, 0, $EVNT_HWID, \"$EVENT_DATA\");"
    rtest sql "$EVENT_QUERY"
    /bin/date +%s >> /var/local/upgrade.txt
    exit
fi
echo "First stopping Lighttpd and start upgrading..."
/etc/init.d/lighttpd stop
echo "Stopping Watch Dog"
/etc/init.d/wd stop
# Kill SysFCGI.fx just in case, if sysfcgi process was not stopped with Lighttpd
killall -9 sysfcgi.fx
opkg install replicator.opk --force-downgrade
opkg install sysfcgi.fx.opk --force-downgrade
sleep 6
killall -9 syshwrwx
opkg install syshwrwx.opk --force-downgrade
echo "Checking and installing timezones packages."
if [ `opkg status tzdata|grep "Package:"|wc -l` == 0 ]; then echo "\tInstalling tzdata_2011b-r8.0.6_all.ipk"; opkg -force-depends install /tmp/timezones/tzdata_2011b-r8.0.6_all.ipk --force-downgrade; fi
if [ `opkg status tzdata-right|grep "Package:"|wc -l` == 0 ]; then echo "\tInstalling tzdata-right_2011b-r8.0.6_all.ipk"; opkg -force-depends install /tmp/timezones/tzdata-right_2011b-r8.0.6_all.ipk --force-downgrade; fi
rm -rf /tmp/timezones
echo "Clean /etc/default/hwclock if it is full of UTC=yes."
cat /etc/default/hwclock | sort -u > /etc/default/hwclock.tmp
mv /etc/default/hwclock.tmp /etc/default/hwclock
echo "Update CentralAPI."
mkdir -p /home/python/CentralAPI
cp /tmp/CentralAPI/* /home/python/CentralAPI/
rm -rf /tmp/CentralAPI
if [ $CLEANDB = "UseInstallDB" ]; 
then
echo "Overwriting DB with empty install DB"
/etc/init.d/replicator stop
cp /var/local/install_prima_config.db /var/local/prima_config.db
cp /var/local/install_prima_events.db /var/local/prima_events.db
/etc/init.d/replicator start
echo -e "\tWait replicator to start up..."
ERROR=1
while [ $ERROR != 0 ]; do
	rtest sql "SELECT SetID FROM Settings LIMIT 1;"
	let ERROR=$?
	if [ "$ERROR" = "0" ]; then
		echo -e "\tReplicator started."
	else
		echo -e "\tWaiting Replicator to start... Error: $ERROR."
		sleep 1
	fi
done
/etc/init.d/lighttpd restart
sleep 3
/etc/init.d/syshwrwx restart
fi
opkg install wd.opk --force-downgrade
echo "Write packages versions"
opkg status replicator | grep Version > /var/local/versions.txt;
opkg status syshwrwx | grep Version >> /var/local/versions.txt;
opkg status sysfcgi.fx | grep Version >> /var/local/versions.txt;
which python >> /var/local/versions.txt; sleep 1;
sync
TIME_UTC=$(rtest sql "SELECT strftime('%s', 'now', 'localtime');" | tail -1)
TIME=${TIME_UTC:4:10}
EVENT_DATA=$(cat /var/local/versions.txt)
EVENT_DATA=$(echo "$EVENT_DATA" | tr '\n' ' ')
EVENT_DATA=${EVENT_DATA/'Version'/'Replicator'}
EVENT_DATA=${EVENT_DATA/'Version'/'SysHwRWX'}
EVENT_DATA=${EVENT_DATA/'Version'/'SysFCGI'}
EVENT_DATA=$(echo "$EVENT_DATA" | tr / '-')
EVENT_DATA=${EVENT_DATA/'-usr-bin-python'/'Python 2.6.6'}
EVENT_QUERY="INSERT INTO Events (EvntDateTime, EvntDscID, UsrID, HwID, EvntData) VALUES($TIME, 2007, 0, $EVNT_HWID, \"$EVENT_DATA\");"
echo "Event query: $EVENT_QUERY"
rtest sql "$EVENT_QUERY"
/bin/date +%s >> /var/local/upgrade.txt
